=============
Release Notes
=============

Coiled makes regular releases to both `cloud.coiled.io` (Coiled Cloud)
and the ``coiled`` Python package (Coiled Client) that is published to
PyPI and conda-forge. In this page you can choose which release notes you
would like to see.

.. toctree::
   :maxdepth: 1
   :hidden:

   cloud_changelog
   changelog

.. panels::
   :body: text-center
   :header: text-center h5 bg-white
   :footer: border-2 bg-white

   | Coiled Cloud 
   | Release Notes

   .. link-button:: cloud_changelog
      :type: ref
      :text: Go to release notes
      :classes: btn-full btn-block stretched-link

   ---

   | Coiled Client 
   | Release Notes

   .. link-button:: changelog
      :type: ref
      :text: Go to release notes
      :classes: btn-full btn-block stretched-link
